@@ -14,17 +14,17 @@ from .trigonometry import to_polar
 from ._data import get_tlvs
 
 VALID_LAMPS = [
+    "aerolamp",
     "beacon",
     "lumenizer_zone",
+    "nukit_lantern",
+    "nukit_torch",
     "sterilray",
     "ushio_b1",
     "ushio_b1.5",
     "uvpro222_b1",
     "uvpro222_b2",
     "visium",
-    "aerolamp",
-    "nukit_torch",
-    "nukit_lantern",
 ]
 
 KRCL_KEYS = [
@@ -270,14 +270,12 @@ class Lamp:
     @property
     def keywords(self):
         return VALID_LAMPS
-
+        
     @classmethod
     def from_keyword(cls, key, lamp_id=None, **kwargs):
         """define a Lamp object from a predefined keyword"""
-
         if not isinstance(key, str):
             raise TypeError(f"Keyword must be str, not {type(key)}")
-
         if key.lower() in VALID_LAMPS:
             path = "guv_calcs.data.lamp_data"
             fn = resources.files(path).joinpath(key.lower() + ".ies")
@@ -316,6 +314,29 @@ class Lamp:
 
         return cls(**kwargs)
 
+    @classmethod
+    def from_index(cls, key_index=0, lamp_id=None, **kwargs):
+        """define a Lamp object from an index value"""
+        if not isinstance(key_index, int):
+            raise TypeError(f"Keyword index must be int, not {type(key_index)}")
+        if key_index < len(VALID_LAMPS):
+            key = VALID_LAMPS[key_index]
+            path = "guv_calcs.data.lamp_data"
+            fname = key.lower() + ".ies"
+            spec_fname = key.lower() + ".csv"
+            filename = resources.files(path).joinpath(fname)
+            spectra_source = resources.files(path).joinpath(spec_fname)
+            kwargs.setdefault("filedata", filename)
+            kwargs.setdefault("spectra_source", spectra_source)
+        else:
+            raise IndexError(
+                f"Only {len(VALID_LAMPS)} lamps are available. Available lamps: {VALID_LAMPS}"
+            )
+            
+        kwargs.setdefault("lamp_id", key)
+        
+        return cls(**kwargs)
+
     def get_calc_state(self):
         """
         return a set of paramters that, if changed, indicate that
@@ -461,7 +482,7 @@ class Lamp:
     @property
     def bank(self):
         return self.pose.bank
-
+        
     def move(self, x=None, y=None, z=None):
         """Designate lamp position in cartesian space"""
         self.pose = self.pose.move(x=x, y=y, z=z)
@@ -636,7 +657,6 @@ class Lamp:
         else:
             self.photometry.scale(scale_val / self.scaling_factor)
             self._update_scaling_factor()
-            # self._scale_mode = "factor"
         return self
 
     def scale_to_max(self, max_val):
@@ -650,7 +670,6 @@ class Lamp:
             else:
                 self.ies.photometry.scale_to_max(max_val)
             self._update_scaling_factor()
-            # self._scale_mode = "max"
         return self
 
     def scale_to_total(self, total_power):
@@ -661,7 +680,6 @@ class Lamp:
         else:
             self.ies.photometry.scale_to_total(total_power)
             self._update_scaling_factor()
-            # self._scale_mode = "total"
         return self
 
     def scale_to_center(self, center_val):
@@ -706,7 +724,8 @@ class Lamp:
 
     def set_units(self, units):
         """set units"""
-        self.ies.update(units=1 if units == "feet" else 2)
+        if self.ies is not None:
+            self.ies.update(units=1 if units == "feet" else 2)
         self.surface.set_units(units)
         return self
 
